PALM-meteo: palmmeteo.runtime Namespace Reference

PALM-meteo

Loading...
Searching...
No Matches
Classes | Functions | Variables
palmmeteo.runtime Namespace Reference

## Classes
class | RuntimeObj

## Functions
| myopen (fpath, *args, **kwargs)
| basic_init (rt)

## Variables
| zstd = None
| rt = RuntimeObj()

## Function Documentation

## ◆ basic_init()

palmmeteo.runtime.basic_init | ( |  | rt | ) |

    Performs initializaiton of basic values from config.

## ◆ myopen()

palmmeteo.runtime.myopen | ( |  | fpath,
|  | * | args,
|  | ** | kwargs
| ) |  |

## Variable Documentation

## ◆ rt

palmmeteo.runtime.rt = RuntimeObj()

## ◆ zstd

palmmeteo.runtime.zstd = None